@@ -175,7 +175,7 @@ static void dialog_response (GtkDialog *dialog,
         gint time = 20;
         if (picker != NULL)
         {
-          gint index = hildon_picker_button_get_active (picker);
+          gint index = hildon_picker_button_get_active (HILDON_PICKER_BUTTON(picker));
           if (index >= 0 && index < 6)
           {
             int times[] = {5, 10, 15, 20, 25, 30};
